@@ -41,7 +41,7 @@ from lxml import etree
 from nikola.plugin_categories import Command
 from nikola import utils, hierarchy_utils
 from nikola.nikola import DEFAULT_TRANSLATIONS_PATTERN
-from nikola.utils import req_missing, unicode_str
+from nikola.utils import req_missing
 from nikola.plugins.basic_import import ImportMixin, links
 from nikola.plugins.command.init import (
     SAMPLE_CONF, prepare_config,
@@ -398,7 +398,7 @@ to
         # Add tag redirects
         for tag in self.all_tags:
             try:
-                if isinstance(tag, utils.bytes_str):
+                if isinstance(tag, bytes):
                     tag_str = tag.decode('utf8', 'replace')
                 else:
                     tag_str = tag
@@ -499,11 +499,11 @@ to
         context['POSTS'] = POSTS
         context['PAGES'] = PAGES
         COMPILERS = '{\n'
-        COMPILERS += '''    "rest": ('.txt', '.rst'),''' + '\n'
-        COMPILERS += '''    "markdown": ('.md', '.mdown', '.markdown'),''' + '\n'
-        COMPILERS += '''    "html": ('.html', '.htm'),''' + '\n'
+        COMPILERS += '''    "rest": ['.txt', '.rst'],''' + '\n'
+        COMPILERS += '''    "markdown": ['.md', '.mdown', '.markdown'],''' + '\n'
+        COMPILERS += '''    "html": ['.html', '.htm'],''' + '\n'
         if self.use_wordpress_compiler:
-            COMPILERS += '''    "wordpress": ('.wp'),''' + '\n'
+            COMPILERS += '''    "wordpress": ['.wp'],''' + '\n'
         COMPILERS += '}'
         context['COMPILERS'] = COMPILERS
 
@@ -803,7 +803,7 @@ to
             """Write comment header line."""
             if header_content is None:
                 return
-            header_content = unicode_str(header_content).replace('\n', ' ')
+            header_content = str(header_content).replace('\n', ' ')
             line = '.. ' + header_field + ': ' + header_content + '\n'
             fd.write(line.encode('utf8'))
 
@@ -890,7 +890,7 @@ to
         path = unquote(parsed.path.strip('/'))
 
         try:
-            if isinstance(path, utils.bytes_str):
+            if isinstance(path, bytes):
                 path = path.decode('utf8', 'replace')
             else:
                 path = path
@@ -1210,7 +1210,7 @@ def modernize_qtranslate_tags(xml_bytes):
     """
     Uniformize the "tag" used by various version of qtranslate.
 
-    The resutling byte string will only contain one set of qtranslate tags
+    The resulting byte string will only contain one set of qtranslate tags
     (namely [:LG] and [:]), older ones being converted to new ones.
     """
     old_start_lang = re.compile(b"<!--:?(\\w{2})-->")
