@@ -31,11 +31,13 @@ import json
 import os
 
 try:
+    import nbconvert
     from nbconvert.exporters import HTMLExporter
     import nbformat
     current_nbformat = nbformat.current_nbformat
     from jupyter_client import kernelspec
     from traitlets.config import Config
+    NBCONVERT_VERSION_MAJOR = int(nbconvert.__version__.partition(".")[0])
     flag = True
 except ImportError:
     flag = None
@@ -60,7 +62,10 @@ class CompileIPynb(PageCompiler):
         c = Config(get_default_jupyter_config())
         c.merge(Config(self.site.config['IPYNB_CONFIG']))
         if 'template_file' not in self.site.config['IPYNB_CONFIG'].get('Exporter', {}):
-            c['Exporter']['template_file'] = 'basic.tpl'  # not a typo
+            if NBCONVERT_VERSION_MAJOR >= 6:
+                c['Exporter']['template_file'] = 'classic/base.html.j2'
+            else:
+                c['Exporter']['template_file'] = 'basic.tpl'  # not a typo
         exportHtml = HTMLExporter(config=c)
         body, _ = exportHtml.from_notebook_node(nb_json)
         return body
@@ -82,8 +87,8 @@ class CompileIPynb(PageCompiler):
     def compile(self, source, dest, is_two_file=False, post=None, lang=None):
         """Compile the source file into HTML and save as dest."""
         makedirs(os.path.dirname(dest))
-        with io.open(dest, "w+", encoding="utf8") as out_file:
-            with io.open(source, "r", encoding="utf8") as in_file:
+        with io.open(dest, "w+", encoding="utf-8") as out_file:
+            with io.open(source, "r", encoding="utf-8-sig") as in_file:
                 nb_str = in_file.read()
             output, shortcode_deps = self.compile_string(nb_str, source,
                                                          is_two_file, post,
@@ -107,7 +112,7 @@ class CompileIPynb(PageCompiler):
         if lang is None:
             lang = LocaleBorg().current_lang
         source = post.translated_source_path(lang)
-        with io.open(source, "r", encoding="utf8") as in_file:
+        with io.open(source, "r", encoding="utf-8-sig") as in_file:
             nb_json = nbformat.read(in_file, current_nbformat)
         # Metadata might not exist in two-file posts or in hand-crafted
         # .ipynb files.
@@ -156,7 +161,7 @@ class CompileIPynb(PageCompiler):
         if onefile:
             nb["metadata"]["nikola"] = metadata
 
-        with io.open(path, "w+", encoding="utf8") as fd:
+        with io.open(path, "w+", encoding="utf-8") as fd:
             nbformat.write(nb, fd, 4)
 
 
